@@ -1,7 +1,7 @@
 use std::collections::BTreeMap;
 
 use deser::de::{Deserialize, DeserializerState, Driver, Sink, SinkHandle};
-use deser::{Error, Event};
+use deser::{Atom, Error, Event};
 use deser_path::{Path, PathSink};
 
 #[derive(Debug, PartialEq, Eq)]
@@ -16,11 +16,16 @@ impl Deserialize for MyBool {
 }
 
 impl Sink for SlotWrapper<MyBool> {
-    fn bool(&mut self, value: bool, state: &DeserializerState) -> Result<(), Error> {
-        let path = state.get::<Path>();
-        assert_eq!(path.segments().len(), 1);
-        **self = Some(MyBool(value));
-        Ok(())
+    fn atom(&mut self, atom: Atom, state: &DeserializerState) -> Result<(), Error> {
+        match atom {
+            Atom::Bool(value) => {
+                let path = state.get::<Path>();
+                assert_eq!(path.segments().len(), 1);
+                **self = Some(MyBool(value));
+                Ok(())
+            }
+            other => Err(other.unexpected_error(&self.expecting())),
+        }
     }
 }
 
@@ -31,12 +36,12 @@ fn test_path() {
     {
         let sink = PathSink::wrap_ref(Deserialize::deserialize_into(&mut out));
         let mut driver = Driver::from_sink(SinkHandle::boxed(sink));
-        driver.emit(&Event::MapStart).unwrap();
-        driver.emit(&Event::Str("foo".into())).unwrap();
-        driver.emit(&Event::Bool(true)).unwrap();
-        driver.emit(&Event::Str("bar".into())).unwrap();
-        driver.emit(&Event::Bool(false)).unwrap();
-        driver.emit(&Event::MapEnd).unwrap();
+        driver.emit(Event::MapStart).unwrap();
+        driver.emit("foo").unwrap();
+        driver.emit(true).unwrap();
+        driver.emit("bar").unwrap();
+        driver.emit(false).unwrap();
+        driver.emit(Event::MapEnd).unwrap();
     }
 
     let map = out.unwrap();
